from tests import app


@app.route("/error-assert-template-variable-not-found")
def error_assert_template_variable_not_found():
    return ""
